@@ -15,6 +15,7 @@ from plone.app.portlets.portlets.rss import RSSFeed
 from plone.app.portlets.portlets.rss import FEED_DATA, Renderer
 from plone.i18n.normalizer import idnormalizer
 from zExceptions import BadRequest
+import urllib2
 
 
 
@@ -58,8 +59,8 @@ class ContentParser:
     """Class used to detect the type of feed and extract the usefull information
     out of it"""
     
-    def __init__(self, item, generator):
-        self.type = ""
+    def __init__(self, item, type):
+        self.type = type
         self.title = ""
         self.image = ""
         self.description = ""
@@ -67,15 +68,10 @@ class ContentParser:
         self.output = ""
         self.url = ""
         self.updated = ""
-    
+        
         # For printing all the keys on the items
         #for obj in item:
             #print("Key: " + obj + "\n")
-    
-        if generator is None:
-            self.type = "Document"
-        else:
-            self.type = "Image"
         
         if item.has_key("title"):
             self.title = item["title"]
@@ -85,8 +81,13 @@ class ContentParser:
             self.url = item["url"]
         if item.has_key("updated"):
             self.updated = item["updated"]
-        if item.has_key("media:content"):
-            self.image = item["media:content"]
+            
+        if self.type is "Flickr":
+            start = self.description[self.description.find("<img src=\"") + 10:]
+            url = start[:start.find("\"")]
+            self.image = url
+        else:
+            self.image = "Nothing"
 
 
 class RemoteFolder(folder.ATFolder):
@@ -140,11 +141,13 @@ class RemoteFolder(folder.ATFolder):
         result = ""
         feedItem = None
         id = ""
-        lastUpdate = getattr(self, "lastUpdated", None)
+        type = self._detectType(feed)
         
         #to print feed properties
         #for obj in dir(feed):
-            #print(obj)
+            #printer = obj + " --- " + self._detectType(feed) 
+            #print(printer)
+            
         
         if feed.needs_update:
             feed.update()
@@ -153,7 +156,7 @@ class RemoteFolder(folder.ATFolder):
             #return result
         
         for item in feed.items:
-            feedItem = ContentParser(item, getattr(item, "generator", None))
+            feedItem = ContentParser(item, type)
             result += "<h1>" + feedItem.title  + "</h1>" + "<BR />" + feedItem.description + "<BR />"
             #ADD PLONE CONTENT HERE
             title = feedItem.title
@@ -162,14 +165,44 @@ class RemoteFolder(folder.ATFolder):
             if hasattr(container, id):
                 #If the item exists we continue to the next one
                 continue
-           
+        
             #And now we create our content
-            container.invokeFactory(type_name="Document", id=id, title=feedItem.title)
-            obj = container[id]
-            obj.setText(feedItem.description)
-            obj.portal_workflow.doActionFor(obj, "publish", comment="Remote content automatically published")
+            if type is "Other":
+                self._createPage(container, feedItem, id)
+            elif type is "Flickr":
+                self._createImage(container, feedItem, id)
         
         return result
+       
+    def _createPage(self, container, feedItem, id):
+        container.invokeFactory(type_name="Document", id=id, title=feedItem.title)
+        obj = container[id]
+        obj.setText(feedItem.description)
+        obj.portal_workflow.doActionFor(obj, "publish", comment="Remote content automatically published")
+        
+    def _createImage(self, container, feedItem, id):
+        container.invokeFactory(type_name="Image", id=id, title=feedItem.title)
+        obj = container[id]
+        #print(feedItem.image)
+        try:
+            imageFile = urllib2.urlopen(feedItem.image)
+            imageData = imageFile.read()
+            obj.edit(file=imageData)
+            imageFile.close()
+        except HTTPError:
+            return None
+        
+
+        
+    def _detectType(self, feed):
+        """Detects if the feed comes from a known source that requires special treatment as for example Flickr"""
+        feedUrl = feed.siteurl
+        
+        if "www.flickr.com" in feedUrl:
+            return "Flickr"
+        else:
+            return "Other"
+        
         
     def Update(self):
         """Update is used to update feed data and create plone objects"""
